@@ -150,6 +150,7 @@ the following config variables are pre-defined in the :ref:`main config section
   environment variable with the name `AE_OPTIONS_LOG_FILE` to overwrite the value of the
   :ref:`pre-defined config option/variable <pre-defined-config-options>` `log_file`.
 
+
 .. _config-options:
 
 config options
@@ -224,13 +225,12 @@ from ae.core import (
 from ae.literal import Literal                                                              # type: ignore
 
 
-__version__ = '0.3.66'
+__version__ = '0.3.71'
 
 
 MAIN_SECTION_NAME: str = 'aeOptions'            #: default name of main config section
 
-# lock to prevent errors in config var value changes and reloads/reads
-config_lock = threading.RLock()
+config_lock = threading.RLock()                 # lock to prevent errors in config var value changes and reloads/reads
 
 
 def config_value_string(value: Any) -> str:
@@ -275,7 +275,7 @@ def sh_exec(command_line: str, extra_args: Sequence = (), console_input: str = "
     try:
         result = subprocess.run(args, stdout=pipe, stderr=pipe, input=console_input.encode(), check=True, shell=shell)
     except subprocess.CalledProcessError as ex:                                             # pragma: no cover
-        debug_out(f"****  subprocess.run({args}) returned non-zero exit code {ex.returncode}; exception={ex}")
+        debug_out(f"****  subprocess.run({args=}) returned non-zero exit code {ex.returncode}; {ex=}")
         result = ex
     except Exception as ex:
         print_out(f"****  subprocess.run({args}) raised exception {ex}")
@@ -622,24 +622,28 @@ class ConsoleApp(AppBase):
 
     def get_variable(self, name: str, section: Optional[str] = None, default_value: Optional[Any] = None,
                      cfg_parser: Optional[ConfigParser] = None, value_type: Optional[Type] = None) -> Any:
-        """ determine value of a :ref:`config option <config-options>` or a :ref:`config variable <config-variables>`.
+        """ get value of :ref:`config option <config-options>`, OS environ or :ref:`config variable <config-variables>`.
 
-        :param name:            id/name of a :ref:`config option <config-options>` or the name of an existing/declared
+        :param name:            name of a :ref:`config option <config-options>` or of an existing/declared
                                 :ref:`config variable <config-variables>`.
         :param section:         name of the :ref:`config section <config-sections>`. defaulting to the app options
                                 section (:data:`MAIN_SECTION_NAME`) if not specified or if None or empty string passed.
+                                if :paramref:`~get_variable.name` specifies a user-specific config option then its
+                                value will get retrieved from the user-specific section (section name gets then
+                                extended with help of the :meth:`.user_section` method).
         :param default_value:   default value to return if config value is not specified in any config file.
         :param cfg_parser:      optional ConfigParser instance to use (def= :attr:`~ConsoleApp._cfg_parser`).
         :param value_type:      optional type of the config value. only used for :ref:`config-variables` and
                                 ignored for :ref:`config-options`.
-        :return:                variable value which will be searched in the OS environment, the :ref:`config-options`
+        :return:                variable value which will be searched in the :ref:`config-options`, the OS environment
                                 and in the :ref:`config-variables` in the following order and manner:
 
+                                * **config option** with a name equal to the :paramref:`~get_variable.name` argument
+                                  (only if the passed :paramref:`~get_variable.section` value is either empty,
+                                  None or equal to :data:`MAIN_SECTION_NAME`).
                                 * **OS environment variable** with a matching snake+upper-cased name, compiled from
-                                  the :paramref:`~get_variable.section` and :paramref:`~get_variable.name` arguments.
-                                * **config option** with an id equal to the :paramref:`~get_variable.name` argument
-                                  and with a passed :paramref:`~get_variable.section` value that is either empty,
-                                  None or equal to the value of :data:`MAIN_SECTION_NAME`.
+                                  the :paramref:`~get_variable.section` and :paramref:`~get_variable.name` arguments,
+                                  separated by an underscore character.
                                 * **config variable** with a name and section equal to the values passed into
                                   the :paramref:`~get_variable.name` and :paramref:`~get_variable.section` arguments.
 
@@ -648,11 +652,11 @@ class ConsoleApp(AppBase):
         this method has an alias named :meth:`get_var`.
         """
         section = section or MAIN_SECTION_NAME
-        val = env_str(section + '_' + name, convert_name=True)
-        if val is None:
-            if name in self.cfg_options and section == MAIN_SECTION_NAME:
-                val = self.cfg_options[name].value
-            else:
+        if name in self.cfg_options and section == MAIN_SECTION_NAME:
+            val = self.cfg_options[name].value
+        else:
+            val = env_str(section + '_' + name, convert_name=True)
+            if val is None:
                 lit = Literal(literal_or_value=default_value, value_type=value_type, name=name)  # used for convert/eval
                 lit.value = self._get_cfg_parser_val(name, section=self.user_section(section, name),
                                                      default_value=lit.value, cfg_parser=cfg_parser)
@@ -683,7 +687,7 @@ class ConsoleApp(AppBase):
 
         this method has an alias named :meth:`set_var`.
         """
-        msg = f"****  ConsoleApp.set_var({name!r}, {value!r}) "
+        msg = f"****  ConsoleApp.set_variable({name=!r}, {value=!r}) "
         cfg_fnam = cfg_fnam or self._main_cfg_fnam
         section = section or MAIN_SECTION_NAME
         if name in self.cfg_options and section == MAIN_SECTION_NAME:
@@ -720,6 +724,36 @@ class ConsoleApp(AppBase):
 
     set_var = set_variable  #: alias of method :meth:`.set_variable`
 
+    def del_section(self, section: str, cfg_fnam: Optional[str] = None):
+        """ delete section from the main or the specified config file.
+
+        :param section:         name of the :ref:`config section <config-sections>` to delete/remove.
+        :param cfg_fnam:        optional path/name of the config file (def= :attr:`~ConsoleApp._main_cfg_fnam`).
+        :return:                empty string on success else error message text.
+        """
+        msg = f"****  ConsoleApp.del_section({section=}, {cfg_fnam=}) "
+        cfg_fnam = cfg_fnam or self._main_cfg_fnam
+        if not cfg_fnam or not os.path.isfile(cfg_fnam):
+            return msg + f"INI/CFG file {cfg_fnam} not found."
+
+        err_msg = ''
+        with config_lock:
+            try:
+                cfg_parser = instantiate_config_parser()
+                cfg_parser.read(cfg_fnam)
+
+                assert cfg_parser.remove_section(section), f"{section=} not found in {cfg_fnam=}"
+
+                with open(cfg_fnam, 'w') as configfile:
+                    cfg_parser.write(configfile)
+                self.load_cfg_files(config_modified=False)
+                self.load_user_cfg()
+
+            except Exception as ex:
+                err_msg = msg + f"exception: {ex}"
+
+        return err_msg
+
     def add_argument(self, *args, **kwargs):
         """ define new command line argument.
 
@@ -791,7 +825,7 @@ class ConsoleApp(AppBase):
         # determine config value to use as default for command line arg
         option = Literal(literal_or_value=False if value is UNSET else value, name=name)
         # alt: cfg_val = self._get_cfg_parser_val(name, self.user_section(MAIN_SECTION_NAME, name), default_value=value)
-        cfg_val = self.get_var(name, section=MAIN_SECTION_NAME, default_value=False if value is UNSET else value)
+        cfg_val = self.get_variable(name, section=MAIN_SECTION_NAME, default_value=False if value is UNSET else value)
         option.value = cfg_val
         kwargs = dict(help=desc, default=cfg_val)
         if value is UNSET:
@@ -977,14 +1011,15 @@ class ConsoleApp(AppBase):
             self.set_var(var_name + '_' + user_id, self.get_var(var_name, default_value=-3))
             self.set_var(var_name, 0)  # reset onboarding tour start counter cfg var for other, non-registered OS users
 
-    def user_section(self, section: str, name: str) -> str:
+    def user_section(self, section: str, name: str = "") -> str:
         """ return the user section name if the passed (section, name) setting id is user-specific.
 
         :param section:         section name.
-        :param name:            variable name.
+        :param name:            config variable name. if specified then this variable has to be a user-specific one.
+                                if not specified and the user is registered then return always the user section.
         :return:                passed section name or user-specific section name.
         """
-        if self.user_id in self.registered_users and (section, name) in self.user_specific_cfg_vars:
+        if self.user_id in self.registered_users and (not name or (section, name) in self.user_specific_cfg_vars):
             section = section + '_usr_id_' + self.user_id
         return section
 
